pub struct Source { /* private fields */ }Implementations
Sourceimpl Source
impl Source
Sourcepub fn new(ctx: &mut Context, path: &str) -> GameResult<Source>
pub fn new(ctx: &mut Context, path: &str) -> GameResult<Source>
Load audio file.
Attempts to automatically detect the format of the source of data.
Sourcepub fn from_bytes(ctx: &mut Context, bytes: &[u8]) -> GameResult<Source>
pub fn from_bytes(ctx: &mut Context, bytes: &[u8]) -> GameResult<Source>
Load audio from file.
Attempts to automatically detect the format of the source of data.
pub fn play(&self, ctx: &mut Context) -> GameResult<()>
pub fn stop(&self, ctx: &mut Context) -> GameResult
pub fn set_volume(&mut self, ctx: &mut Context, volume: f32) -> GameResult<()>
pub fn volume(&self) -> f32
pub fn set_repeat(&mut self, repeat: bool)
pub fn repeat(&self) -> bool