pub enum GameError {
IOError(Error),
ShaderProgramError(String),
GamepadError(String),
LyonError(String),
MixerNotCreated,
SoundError,
UnknownError(String),
ResourceNotFound(String, Vec<(PathBuf, GameError)>),
FilesystemError(String),
ResourceLoadError(String),
RenderError(String),
CustomError(String),
}Expand description
An enum containing all kinds of game framework errors.
Variants
IOError(Error)
Something went wrong trying to read from a file
ShaderProgramError(String)
Something went wrong compiling shaders
GamepadError(String)
Something went wrong with the gilrs gamepad-input library.
LyonError(String)
Something went wrong with the lyon shape-tesselation library
MixerNotCreated
SoundMixer in the context should be created explicitly from some of the interaction callbacks Thats the only way to get audio to works on web :(
SoundError
UnknownError(String)
ResourceNotFound(String, Vec<(PathBuf, GameError)>)
Unable to find a resource; the Vec is the paths it searched for and associated errors
FilesystemError(String)
An error in the filesystem layout
ResourceLoadError(String)
An error trying to load a resource, such as getting an invalid image file.
RenderError(String)
Something went wrong in the renderer
CustomError(String)
A custom error type for use by users of ggez. This lets you handle custom errors that may happen during your game (such as, trying to load a malformed file for a level) using the same mechanism you handle ggez’s other errors.
Please include an informative message with the error.