SceneStack

Struct SceneStack 

pub struct SceneStack<C> {
    pub world: C,
    /* private fields */
}
A stack of Scene’s, together with a context object.

Fields

world: C

Implementations

Source

impl<C> SceneStack<C>

pub fn new(_ctx: &mut Context, global_state: C) -> Self

pub fn push(&mut self, scene: Box<dyn Scene<C>>)

Add a new scene to the top of the stack.

pub fn pop(&mut self) -> Box<dyn Scene<C>>

Remove the top scene from the stack and returns it; panics if there is none.

pub fn current(&self) -> &dyn Scene<C>

Returns the current scene; panics if there is none.

pub fn switch( &mut self, next_scene: SceneSwitch<C>, ) -> Option<Box<dyn Scene<C>>>

Executes the given SceneSwitch command; if it is a pop or replace it returns Some(old_scene), otherwise None

pub fn update(&mut self, ctx: &mut Context, quad_ctx: &mut GraphicsContext)

pub fn draw(&mut self, ctx: &mut Context, quad_ctx: &mut GraphicsContext)

Draw the current scene.