pub enum Align {
Left,
Center,
Right,
}Expand description
Describes horizontal alignment preference for positioning & bounds.
Variants
Left
Leftmost character is immediately to the right of the render position.
Bounds start from the render position and advance rightwards.
Center
Leftmost & rightmost characters are equidistant to the render position.
Bounds start from the render position and advance equally left & right.
Right
Rightmost character is immetiately to the left of the render position.
Bounds start from the render position and advance leftwards.