DrawParam

Struct DrawParam 

pub struct DrawParam {
    pub src: Rect,
    pub color: Color,
    pub trans: Transform,
}

Fields

src: Rect

A portion of the drawable to clip, as a fraction of the whole image. Defaults to the whole image (0,0 to 1,1) if omitted.

color: Color

A color to draw the target with. Default: white.

trans: Transform

Where to put the Drawable.

Implementations

Source

impl DrawParam

pub fn new() -> Self

Create a new DrawParam with default values.

pub fn src(self, src: Rect) -> Self

Set the source rect

pub fn dest<P>(self, dest_: P) -> Self
where P: Into<Point2<f32>>,

Set the dest point

pub fn color(self, color: Color) -> Self

Set the drawable color. This will be blended with whatever color the drawn object already is.

pub fn rotation(self, rot: f32) -> Self

Set the rotation of the drawable.

pub fn scale<V>(self, scale_: V) -> Self
where V: Into<Vector2<f32>>,

Set the scaling factors of the drawable.

pub fn offset<P>(self, offset_: P) -> Self
where P: Into<Point2<f32>>,

Set the transformation offset of the drawable.

pub fn transform<M>(self, transform: M) -> Self
where M: Into<ColumnMatrix4<f32>>,

Set the transformation matrix of the drawable.