pub struct Image { /* private fields */ }Implementations
Sourceimpl Image
impl Image
pub fn new<P: AsRef<Path>>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, path: P, ) -> GameResult<Self>
pub fn from_png_bytes( ctx: &mut Context, quad_ctx: &mut GraphicsContext, bytes: &[u8], ) -> GameResult<Self>
pub fn from_rgba8( ctx: &mut Context, quad_ctx: &mut GraphicsContext, width: u16, height: u16, bytes: &[u8], ) -> GameResult<Image>
pub fn from_texture( ctx: &mut Context, texture: Texture, filter: FilterMode, ) -> GameResult<Image>
Sourcepub fn solid(
context: &mut Context,
quad_ctx: &mut GraphicsContext,
size: u16,
color: Color,
) -> GameResult<Self>
pub fn solid( context: &mut Context, quad_ctx: &mut GraphicsContext, size: u16, color: Color, ) -> GameResult<Self>
A little helper function that creates a new Image that is just
a solid square of the given size and color. Mainly useful for
debugging.
pub fn width(&self) -> u16
pub fn height(&self) -> u16
Sourcepub fn dimensions(&self) -> Rect
pub fn dimensions(&self) -> Rect
Returns the dimensions of the image.
pub fn set_filter(&mut self, filter: FilterMode)
pub fn filter(&self) -> FilterMode