Mesh

Struct Mesh 

pub struct Mesh { /* private fields */ }
2D polygon mesh.

All of its creation methods are just shortcuts for doing the same operation via a MeshBuilder.

Implementations

Source

impl Mesh

pub fn new_line<P>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, points: &[P], width: f32, color: Color, ) -> GameResult<Mesh>
where P: Into<Point2<f32>> + Clone,

Create a new mesh for a line of one or more connected segments.

pub fn new_circle<P>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, mode: DrawMode, point: P, radius: f32, tolerance: f32, color: Color, ) -> GameResult<Mesh>
where P: Into<Point2<f32>>,

Create a new mesh for a circle.

pub fn new_ellipse<P>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, mode: DrawMode, point: P, radius1: f32, radius2: f32, tolerance: f32, color: Color, ) -> GameResult<Mesh>
where P: Into<Point2<f32>>,

Create a new mesh for an ellipse.

pub fn new_polyline<P>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, mode: DrawMode, points: &[P], color: Color, ) -> GameResult<Mesh>
where P: Into<Point2<f32>> + Clone,

Create a new mesh for series of connected lines.

pub fn new_polygon<P>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, mode: DrawMode, points: &[P], color: Color, ) -> GameResult<Mesh>
where P: Into<Point2<f32>> + Clone,

Create a new mesh for closed polygon. The points given must be in clockwise order, otherwise at best the polygon will not draw.

pub fn new_rectangle( ctx: &mut Context, quad_ctx: &mut GraphicsContext, mode: DrawMode, bounds: Rect, color: Color, ) -> GameResult<Mesh>

Create a new mesh for a rectangle

pub fn new_rounded_rectangle( ctx: &mut Context, quad_ctx: &mut GraphicsContext, mode: DrawMode, bounds: Rect, radius: f32, color: Color, ) -> GameResult<Mesh>

Create a new mesh for a rounded rectangle

pub fn from_triangles<P>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, triangles: &[P], color: Color, ) -> GameResult<Mesh>
where P: Into<Point2<f32>> + Clone,

Create a new Mesh from a raw list of triangle points.

pub fn from_raw<V>( ctx: &mut Context, quad_ctx: &mut GraphicsContext, verts: &[V], indices: &[u16], image: Option<Image>, ) -> GameResult<Mesh>
where V: Into<Vertex> + Clone,

Creates a Mesh from a raw list of triangles defined from points and indices, with the given UV texture coordinates. You may also supply an Image to use as a texture, if you pass None, it will just use a pure white texture.

This is the most primitive mesh-creation method, but allows you full control over the tesselation and texturing. As such it will panic or produce incorrect/invalid output (that may later cause drawing to panic), if:

  • indices contains a value out of bounds of verts
  • verts is longer than u16::MAX elements.