MeshBatch

Struct MeshBatch 

pub struct MeshBatch { /* private fields */ }
Mesh that will be rendered with hardware instancing. Use this when you have a lot of similar geometry which does not move around often.

Implementations

Source

impl MeshBatch

pub fn new(mesh: Mesh) -> GameResult<MeshBatch>

Creates a new mesh batch.

Takes ownership of the Mesh.

pub fn clear(&mut self)

Removes all instances from the batch.

Calling this invalidates the entire buffer, however this will not automatically deallocate graphics card memory or flush the buffer.

pub fn get_instance_params(&self) -> &[DrawParam]

Returns a reference to mesh instances

pub fn get_instance_params_mut(&mut self) -> &mut [DrawParam]

Returns a mutable reference to mesh instances.

Please note that manually altering items in this slice will not automatically invalidate the buffer, you will have to manually call flush() or flush_range() later.

pub fn add<P>(&mut self, param: P) -> MeshIdx
where P: Into<DrawParam>,

Adds a new instance to the mesh batch

Returns a handle with which to modify the instance using set()

Calling this invalidates the entire buffer and will result in flusing it on the next graphics::draw() call.

pub fn set<P>(&mut self, handle: MeshIdx, param: P) -> GameResult
where P: Into<DrawParam>,

Alters an instance in the batch to use the given draw params.

Calling this invalidates the entire buffer and will result in flusing it on the next graphics::draw() call.

This might cause performance issues with large batches, to avoid this consider using flush_range to explicitly invalidate required data slice.

pub fn set_range<P>( &mut self, first_handle: MeshIdx, params: &[P], ) -> GameResult
where P: Into<DrawParam> + Copy,

Alters a range of instances in the batch to use the given draw params

Calling this invalidates the entire buffer and will result in flusing it on the next graphics::draw() call.

This might cause performance issues with large batches, to avoid this consider using flush_range to explicitly invalidate required data slice.

pub fn flush_range( &mut self, _ctx: &mut Context, quad_ctx: &mut GraphicsContext, first_handle: MeshIdx, count: usize, ) -> GameResult

Immediately sends specified slice of data in the batch to the graphics card.

Calling this counts as a full buffer flush, but only flushes the data within the provided range, anything outside of this range will not be touched.

Use it for updating small portions of large batches.

pub fn flush( &mut self, ctx: &mut Context, quad_ctx: &mut GraphicsContext, ) -> GameResult

Immediately sends all data in the batch to the graphics card.

In general, graphics::draw() on the MeshBatch will do this automatically when buffer contents are updated.

pub fn draw( &mut self, ctx: &mut Context, quad_ctx: &mut GraphicsContext, param: DrawParam, ) -> GameResult

Draws the drawable onto the rendering target.

pub fn dimensions(&self, ctx: &mut Context) -> Option<Rect>

Returns a bounding box in the form of a Rect.

pub fn set_blend_mode(&mut self, mode: Option<BlendMode>)

Sets the blend mode to be used when drawing this drawable.

pub fn blend_mode(&self) -> Option<BlendMode>

Gets the blend mode to be used when drawing this drawable.