pub struct ShaderLock { /* private fields */ }Expand description
A lock for RAII shader regions. The shader automatically gets cleared once the lock goes out of scope, restoring the previous shader (if any).
Essentially, binding a Shader will return one of these,
and the shader will remain active as long as this object exists. When this is
dropped, the previous shader is restored.