Text

Struct Text 

pub struct Text { /* private fields */ }
Drawable text object. Essentially a list of TextFragment’s and some cached size information.

It implements Drawable so it can be drawn immediately with graphics::draw(), or many of them can be queued with graphics::queue_text() and then all drawn at once with graphics::draw_queued_text().

Implementations

Source

impl Text

pub fn new<F>(fragment: F) -> Text
where F: Into<TextFragment>,

Creates a Text from a TextFragment.

let text = Text::new("foo");
pub fn add<F>(&mut self, fragment: F) -> &mut Text
where F: Into<TextFragment>,

Appends a TextFragment to the Text.

pub fn fragments(&self) -> &[TextFragment]

Returns a read-only slice of all TextFragment’s.

pub fn fragments_mut(&mut self) -> &mut [TextFragment]

Returns a mutable slice with all fragments.

pub fn set_bounds<P>(&mut self, bounds: P, alignment: Align) -> &mut Text
where P: Into<Point2<f32>>,

Specifies rectangular dimensions to try and fit contents inside of, by wrapping, and alignment within the bounds. To disable wrapping, give it a layout with f32::INF for the x value.

pub fn set_font(&mut self, font: Font, font_scale: PxScale) -> &mut Text

Specifies text’s font and font scale; used for fragments that don’t have their own.

pub fn contents(&self) -> String

Returns the string that the text represents.

pub fn glyph_positions(&self, context: &Context) -> Ref<'_, Vec<Point2<f32>>>

Returns a Vec containing the coordinates of the formatted and wrapped text.

pub fn dimensions(&self, context: &Context) -> Rect

Returns a Rect containing the width and height of the formatted and wrapped text.

pub fn width(&self, context: &Context) -> f32

Returns the width of formatted and wrapped text, in screen coordinates.

pub fn height(&self, context: &Context) -> f32

Returns the height of formatted and wrapped text, in screen coordinates.