pub struct TextFragment {
pub text: String,
pub color: Option<Color>,
pub font: Option<Font>,
pub scale: Option<PxScale>,
}Expand description
A piece of text with optional color, font and font scale information.
Drawing text generally involves one or more of these.
These options take precedence over any similar field/argument.
Implements From for char, &str, String and
(String, Font, PxScale).
Fields
text: StringText string itself.
color: Option<Color>Fragment’s color, defaults to text’s color.
font: Option<Font>Fragment’s font, defaults to text’s font.
scale: Option<PxScale>Fragment’s scale, defaults to text’s scale.
Implementations
Sourceimpl TextFragment
impl TextFragment
Sourcepub fn color<C: Into<Color>>(self, color: C) -> TextFragment
pub fn color<C: Into<Color>>(self, color: C) -> TextFragment
Set fragment’s color, overrides text’s color.
Sourcepub fn font(self, font: Font) -> TextFragment
pub fn font(self, font: Font) -> TextFragment
Set fragment’s font, overrides text’s font.
Sourcepub fn scale<S: Into<PxScale>>(self, scale: S) -> TextFragment
pub fn scale<S: Into<PxScale>>(self, scale: S) -> TextFragment
Set fragment’s scale, overrides text’s scale. Default is 16.0