pub struct DrawParam {
pub src: Rect,
pub color: Color,
pub trans: Transform,
}Fields
src: RectA portion of the drawable to clip, as a fraction of the whole image.
Defaults to the whole image (0,0 to 1,1) if omitted.
color: ColorA color to draw the target with. Default: white.
trans: TransformWhere to put the Drawable.
Implementations
Sourceimpl DrawParam
impl DrawParam
Sourcepub fn color(self, color: Color) -> Self
pub fn color(self, color: Color) -> Self
Set the drawable color. This will be blended with whatever color the drawn object already is.