pub struct Font { /* private fields */ }Expand description
A handle referring to a loaded Truetype font.
This is just an integer referring to a loaded font stored in the
Context, so is cheap to copy. Note that fonts are cached and
currently never removed from the cache, since that would
invalidate the whole cache and require re-loading all the other
fonts. So, you do not want to load a font more than once.
Implementations
Sourceimpl Font
impl Font
Sourcepub const DEFAULT_FONT_SCALE: f32 = 16f32
pub const DEFAULT_FONT_SCALE: f32 = 16f32
Default size for fonts.
Sourcepub fn new<P>(context: &mut Context, path: P) -> GameResult<Font>
pub fn new<P>(context: &mut Context, path: P) -> GameResult<Font>
Load a new TTF font from the given file.
Sourcepub fn new_glyph_font_bytes(
context: &mut Context,
bytes: &[u8],
) -> GameResult<Self>
pub fn new_glyph_font_bytes( context: &mut Context, bytes: &[u8], ) -> GameResult<Self>
Loads a new TrueType font from given bytes and into a gfx::GlyphBrush owned
by the Context.