pub struct Rect {
pub x: f32,
pub y: f32,
pub w: f32,
pub h: f32,
}Expand description
A simple 2D rectangle.
The origin of the rectangle is at the top-left, with x increasing to the right and y increasing down.
Fields
x: f32X coordinate of the left edge of the rect.
y: f32Y coordinate of the top edge of the rect.
w: f32Total width of the rect
h: f32Total height of the rect.
Implementations
Sourceimpl Rect
impl Rect
Sourcepub fn fraction(x: f32, y: f32, w: f32, h: f32, reference: &Rect) -> Rect
pub fn fraction(x: f32, y: f32, w: f32, h: f32, reference: &Rect) -> Rect
Creates a new Rect a la Love2D’s love.graphics.newQuad,
as a fraction of the reference rect’s size.
Sourcepub const fn new_i32(x: i32, y: i32, w: i32, h: i32) -> Self
pub const fn new_i32(x: i32, y: i32, w: i32, h: i32) -> Self
Create a new rect from i32 coordinates.
Sourcepub fn contains<P: Into<Point2<f32>>>(&self, point: P) -> bool
pub fn contains<P: Into<Point2<f32>>>(&self, point: P) -> bool
Checks whether the Rect contains a Point
Sourcepub fn translate<V: Into<Vector2<f32>>>(&mut self, offset: V)
pub fn translate<V: Into<Vector2<f32>>>(&mut self, offset: V)
Translates the Rect by an offset of (x, y)
Sourcepub fn move_to<P: Into<Point2<f32>>>(&mut self, destination: P)
pub fn move_to<P: Into<Point2<f32>>>(&mut self, destination: P)
Moves the Rect’s origin to (x, y)
Sourcepub fn scale(&mut self, sx: f32, sy: f32)
pub fn scale(&mut self, sx: f32, sy: f32)
Scales the Rect by a factor of (sx, sy),
growing towards the bottom-left
Sourcepub fn combine_with(self, other: Rect) -> Rect
pub fn combine_with(self, other: Rect) -> Rect
Returns a new Rect that includes all points of these two Rects.