pub struct Text { /* private fields */ }Expand description
Drawable text object. Essentially a list of TextFragment’s
and some cached size information.
It implements Drawable so it can be drawn immediately with
graphics::draw(), or many of them can be queued with graphics::queue_text()
and then all drawn at once with graphics::draw_queued_text().
Implementations
Sourceimpl Text
impl Text
Sourcepub fn new<F>(fragment: F) -> Textwhere
F: Into<TextFragment>,
pub fn new<F>(fragment: F) -> Textwhere
F: Into<TextFragment>,
Creates a Text from a TextFragment.
let text = Text::new("foo");Sourcepub fn add<F>(&mut self, fragment: F) -> &mut Textwhere
F: Into<TextFragment>,
pub fn add<F>(&mut self, fragment: F) -> &mut Textwhere
F: Into<TextFragment>,
Appends a TextFragment to the Text.
Sourcepub fn fragments(&self) -> &[TextFragment]
pub fn fragments(&self) -> &[TextFragment]
Returns a read-only slice of all TextFragment’s.
Sourcepub fn fragments_mut(&mut self) -> &mut [TextFragment]
pub fn fragments_mut(&mut self) -> &mut [TextFragment]
Returns a mutable slice with all fragments.
Sourcepub fn set_bounds<P>(&mut self, bounds: P, alignment: Align) -> &mut Text
pub fn set_bounds<P>(&mut self, bounds: P, alignment: Align) -> &mut Text
Specifies rectangular dimensions to try and fit contents inside of,
by wrapping, and alignment within the bounds. To disable wrapping,
give it a layout with f32::INF for the x value.
Sourcepub fn set_font(&mut self, font: Font, font_scale: PxScale) -> &mut Text
pub fn set_font(&mut self, font: Font, font_scale: PxScale) -> &mut Text
Specifies text’s font and font scale; used for fragments that don’t have their own.
Sourcepub fn glyph_positions(&self, context: &Context) -> Ref<'_, Vec<Point2<f32>>>
pub fn glyph_positions(&self, context: &Context) -> Ref<'_, Vec<Point2<f32>>>
Returns a Vec containing the coordinates of the formatted and wrapped text.
Sourcepub fn dimensions(&self, context: &Context) -> Rect
pub fn dimensions(&self, context: &Context) -> Rect
Returns a Rect containing the width and height of the formatted and wrapped text.